const MongoClient = require('mongodb').MongoClient;
const url = process.env.MONGO_PRERENDER_URL || 'mongodb://localhost:27017/prerender';
const ttl = process.env.PAGE_TTL || 3600 * 7;

let db;

MongoClient.connect(url, function (err, database) {
    if (err) throw err;
    db = database
});

module.exports = {
    get: function (collection, url, callback) {
        db.collection(collection).findOne({url: url}, function (err, res) {
            !err && res ? callback(null, res.value)
                        : callback(err)
        });
    },
    set: function (collection, url, value, callback) {
        db.collection(collection).insertOne({url: url, value: value}, function (err, res) {
            callback(err);
        });

        db.collection(collection).indexInformation(function(err, index) {
            if(!index.createdAt_1) {
                console.log('New index created');
                db.collection(collection).createIndex({createdAt: 1}, {expireAfterSeconds: ttl}, function (err, res) {
                    if(err) callback(err)
                })
            }
        })
    },
    delete: function (collection, url, callback) {
        db.collection(collection).deleteMany({url: url}, function (err, res) {
            callback(err);
        });
    },
    drop: function (collection, callback) {
        db.collection(collection).drop(function (err, res) {
            callback(err);
        });
    }
}
