const { getParsedURL } = require('./utils');
const cacheManager = require('./cacheManager');


module.exports = {

    beforePhantomRequest: function beforePhantomRequest(req, res, next) {
        if (req.method !== 'GET') {
            return next();
        }
        this.url = getParsedURL(req)
        const { collection, path, invalidate } = this.url

        if (invalidate === 'page') {
            cacheManager.delete(collection, path, function (err, result) {
                err ? console.log(`error on page ${path}: ${err}`)
                    : console.log(`cache invalidated on page: ${path}`)
                next();
            })
        } else if (invalidate === 'all') {
            cacheManager.drop(collection, function (err, result) {
                err ? console.log(`error on collection ${collection}: ${err}`)
                    : console.log(`cache invalidated on hostname: ${collection}`)
                next();
            })
        } else {
            cacheManager.get(collection, path, function (err, result) {
                if(err) console.log(`error on page ${path}: ${err}`);

                if (!err && result) {
                    console.log(`cache hit on page: ${path}`);
                    res.send(200, result);
                } else {
                    next();
                }
            });
        }
    },

    afterPhantomRequest: function afterPhantomRequest(req, res, next) {
        const { collection, path } = this.url

        cacheManager.set(
            collection, path, req.prerender.documentHTML, function (err, result) {
                if(err) console.log(`error on set cache page: ${path}: ${err}`)
            });
        next();
    }
};
